GraphicsPrintUtils class

Constructors

GraphicsPrintUtils({PrintPaperSize paperSize = PrintPaperSize.mm80, PrintMargin margin = const PrintMargin(), PrintTextStyle? style = const PrintTextStyle()})

Properties

font ↔ BitmapFont
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
margin PrintMargin
getter/setter pair
paperSize PrintPaperSize
final
runningHeight int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor → ColorUint1
final
utilImage ↔ Image
getter/setter pair

Methods

barcode(String data, {required Barcode barcode, int width = 300, int height = 120, PrintAlign align = PrintAlign.center}) → void
build() Uint8List
Get final image as PNG
dottedLine({int thickness = 1, int dotWidth = 5, int spacing = 3}) → void
Draw dotted horizontal line
feed({int lines = 1}) → void
image(Image subImage, {int? width, int? height, PrintAlign align = PrintAlign.left}) → void
Draw image (resized)
line({int thickness = 1}) → void
Draw horizontal line
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
qr(String data, {int qrSize = 150, PrintAlign align = PrintAlign.center}) → dynamic
Draw QR Code
row({required List<PrintColumn> columns, int spacing = 10}) → void
Draw a row with columns
text(String text, {PrintTextStyle? style}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited