PrintMargin class

Constructors

PrintMargin({int left = 2, int right = 2})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left int
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited