PrintTextStyle class
Constructors
- PrintTextStyle({PrintFontSize fontSize = PrintFontSize.medium, PrintAlign align = PrintAlign.left, bool bold = true})
-
const
Properties
- align → PrintAlign
-
final
- bold → bool
-
final
- fontSize → PrintFontSize
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PrintFontSize? fontSize, PrintAlign? align, bool? bold}) → PrintTextStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited